==> boto_brimley-2.54.0.tar.gz: boto_brimley-2.54.0/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2006-2010 Mitch Garnaat http://garnaat.org/
# Copyright (c) 2010, Eucalyptus Systems, Inc.
# All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish, dis-
# tribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the fol-
# lowing conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABIL-
# ITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT
# SHALL THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.

from __future__ import print_function

try:
    from setuptools import setup
    extra = dict(test_suite="tests.test.suite", include_package_data=True)
except ImportError:
    from distutils.core import setup
    extra = {}

import sys

# from boto import __version__

if sys.version_info <= (2, 5):
    error = "ERROR: boto requires Python Version 2.6 or above...exiting."
    print(error, file=sys.stderr)
    sys.exit(1)

def readme():
    with open("README.rst") as f:
        return f.read()

setup(name = "boto_brimley",
      version = "2.54.0",
      description = "Amazon Web Services Library",
      long_description = readme(),
      author = "Mitch Garnaat",
      author_email = "mitch@garnaat.com",
      scripts = ["bin/sdbadmin", "bin/elbadmin", "bin/cfadmin",
                 "bin/s3put", "bin/fetch_file", "bin/launch_instance",
                 "bin/list_instances", "bin/taskadmin", "bin/kill_instance",
                 "bin/bundle_image", "bin/pyami_sendmail", "bin/lss3",
                 "bin/cq", "bin/route53", "bin/cwutil", "bin/instance_events",
                 "bin/asadmin", "bin/glacier", "bin/mturk",
                 "bin/dynamodb_dump", "bin/dynamodb_load"],
      url = "https://github.com/boto/boto/",
      packages = ["boto_brimley", 'boto_brimley.mws'# "boto_brimley.sqs", "boto_brimley.s3", "boto_brimley.gs", "boto_brimley.file",
                #   "boto_brimley.ec2", "boto_brimley.ec2.cloudwatch", "boto_brimley.ec2.autoscale",
                #   "boto_brimley.ec2.elb", "boto_brimley.sdb", "boto_brimley.cacerts",
                #   "boto_brimley.sdb.db", "boto_brimley.sdb.db.manager",
                #   "boto_brimley.mturk", "boto_brimley.pyami",
                #   "boto_brimley.pyami.installers", "boto_brimley.pyami.installers.ubuntu",
                #   "boto_brimley.mashups", "boto_brimley.contrib", "boto_brimley.manage",
                #   "boto_brimley.services", "boto_brimley.cloudfront",
                #   "boto_brimley.roboto", "boto_brimley.rds", "boto_brimley.vpc", "boto_brimley.fps",
                #   "boto_brimley.fps", "boto_brimley.emr", "boto_brimley.emr", "boto_brimley.sns",
                #   "boto_brimley.ecs", "boto_brimley.iam", "boto_brimley.route53", "boto_brimley.ses",
                #   "boto_brimley.cloudformation", "boto_brimley.sts", "boto_brimley.dynamodb",
                #   "boto_brimley.swf", "boto_brimley.mws", "boto_brimley.cloudsearch", "boto_brimley.glacier",
                #   "boto_brimley.beanstalk", "boto.datapipeline", "boto.elasticache",
                #   "boto_brimley.elastictranscoder", "boto.opsworks", "boto.redshift",
                #   "boto_brimley.dynamodb2", "boto.support", "boto.cloudtrail",
                #   "boto_brimley.directconnect", "boto.kinesis", "boto.rds2",
                #   "boto_brimley.cloudsearch2", "boto.logs", "boto.vendored",
                #   "boto_brimley.route53.domains", "boto.cognito",
                #   "boto_brimley.cognito.identity", "boto.cognito.sync",
                #   "boto_brimley.cloudsearchdomain", "boto.kms",
                #   "boto_brimley.awslambda", "boto.codedeploy", "boto.configservice",
                #   "boto_brimley.cloudhsm", "boto.ec2containerservice",
                #   "boto_brimley.machinelearning", "boto.vendored.regions"
                  ],
      package_data = {
          "boto_brimley.cacerts": ["cacerts.txt"],
          "boto_brimley": ["endpoints.json"],
      },
      license = "MIT",
      platforms = "Posix; MacOS X; Windows",
      classifiers = ["Development Status :: 5 - Production/Stable",
                     "Intended Audience :: Developers",
                     "License :: OSI Approved :: MIT License",
                     "Operating System :: OS Independent",
                     "Topic :: Internet",
                     "Programming Language :: Python :: 2",
                     "Programming Language :: Python :: 2.6",
                     "Programming Language :: Python :: 2.7",
                     "Programming Language :: Python :: 3",
                     "Programming Language :: Python :: 3.3",
                     "Programming Language :: Python :: 3.4"],
      **extra
      )

==> boto_brimley-2.56.0.tar.gz: boto_brimley-2.56.0/setup.py <==
#!/usr/bin/env python

# Copyright (c) 2006-2010 Mitch Garnaat http://garnaat.org/
# Copyright (c) 2010, Eucalyptus Systems, Inc.
# All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish, dis-
# tribute, sublicense, and/or sell copies of the Software, and to permit
# persons to whom the Software is furnished to do so, subject to the fol-
# lowing conditions:
#
# The above copyright notice and this permission notice shall be included
# in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABIL-
# ITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT
# SHALL THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
# IN THE SOFTWARE.

from __future__ import print_function

try:
    from setuptools import setup
    extra = dict(test_suite="tests.test.suite", include_package_data=True)
except ImportError:
    from distutils.core import setup
    extra = {}

import sys

from boto_brimley import __version__

if sys.version_info <= (2, 5):
    error = "ERROR: boto requires Python Version 2.6 or above...exiting."
    print(error, file=sys.stderr)
    sys.exit(1)

def readme():
    with open("README.rst") as f:
        return f.read()

setup(name = "boto_brimley",
      version = __version__,
      description = "Amazon Web Services Library",
      long_description = readme(),
      author = "Mitch Garnaat",
      author_email = "mitch@garnaat.com",
      scripts = ["bin/sdbadmin", "bin/elbadmin", "bin/cfadmin",
                 "bin/s3put", "bin/fetch_file", "bin/launch_instance",
                 "bin/list_instances", "bin/taskadmin", "bin/kill_instance",
                 "bin/bundle_image", "bin/pyami_sendmail", "bin/lss3",
                 "bin/cq", "bin/route53", "bin/cwutil", "bin/instance_events",
                 "bin/asadmin", "bin/glacier", "bin/mturk",
                 "bin/dynamodb_dump", "bin/dynamodb_load"],
      url = "https://github.com/boto/boto/",
      packages = ["boto_brimley", 'boto_brimley.mws'# "boto_brimley.sqs", "boto_brimley.s3", "boto_brimley.gs", "boto_brimley.file",
                #   "boto_brimley.ec2", "boto_brimley.ec2.cloudwatch", "boto_brimley.ec2.autoscale",
                #   "boto_brimley.ec2.elb", "boto_brimley.sdb", "boto_brimley.cacerts",
                #   "boto_brimley.sdb.db", "boto_brimley.sdb.db.manager",
                #   "boto_brimley.mturk", "boto_brimley.pyami",
                #   "boto_brimley.pyami.installers", "boto_brimley.pyami.installers.ubuntu",
                #   "boto_brimley.mashups", "boto_brimley.contrib", "boto_brimley.manage",
                #   "boto_brimley.services", "boto_brimley.cloudfront",
                #   "boto_brimley.roboto", "boto_brimley.rds", "boto_brimley.vpc", "boto_brimley.fps",
                #   "boto_brimley.fps", "boto_brimley.emr", "boto_brimley.emr", "boto_brimley.sns",
                #   "boto_brimley.ecs", "boto_brimley.iam", "boto_brimley.route53", "boto_brimley.ses",
                #   "boto_brimley.cloudformation", "boto_brimley.sts", "boto_brimley.dynamodb",
                #   "boto_brimley.swf", "boto_brimley.mws", "boto_brimley.cloudsearch", "boto_brimley.glacier",
                #   "boto_brimley.beanstalk", "boto.datapipeline", "boto.elasticache",
                #   "boto_brimley.elastictranscoder", "boto.opsworks", "boto.redshift",
                #   "boto_brimley.dynamodb2", "boto.support", "boto.cloudtrail",
                #   "boto_brimley.directconnect", "boto.kinesis", "boto.rds2",
                #   "boto_brimley.cloudsearch2", "boto.logs", "boto.vendored",
                #   "boto_brimley.route53.domains", "boto.cognito",
                #   "boto_brimley.cognito.identity", "boto.cognito.sync",
                #   "boto_brimley.cloudsearchdomain", "boto.kms",
                #   "boto_brimley.awslambda", "boto.codedeploy", "boto.configservice",
                #   "boto_brimley.cloudhsm", "boto.ec2containerservice",
                #   "boto_brimley.machinelearning", "boto.vendored.regions"
                  ],
      package_data = {
          "boto_brimley.cacerts": ["cacerts.txt"],
          "boto_brimley": ["endpoints.json"],
      },
      license = "MIT",
      platforms = "Posix; MacOS X; Windows",
      classifiers = ["Development Status :: 5 - Production/Stable",
                     "Intended Audience :: Developers",
                     "License :: OSI Approved :: MIT License",
                     "Operating System :: OS Independent",
                     "Topic :: Internet",
                     "Programming Language :: Python :: 2",
                     "Programming Language :: Python :: 2.6",
                     "Programming Language :: Python :: 2.7",
                     "Programming Language :: Python :: 3",
                     "Programming Language :: Python :: 3.3",
                     "Programming Language :: Python :: 3.4"],
      **extra
      )
